@@ -3,7 +3,7 @@ package Term::ANSIColor::Conditional;
 ## no critic (Modules::ProhibitAutomaticExportation)
 
 our $DATE = '2018-12-02'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use strict 'subs', 'vars';
 use warnings;
@@ -72,7 +72,7 @@ Term::ANSIColor::Conditional - Colorize text only if color is enabled
 
 =head1 VERSION
 
-This document describes version 0.004 of Term::ANSIColor::Conditional (from Perl distribution Term-ANSIColor-Conditional), released on 2018-12-02.
+This document describes version 0.005 of Term::ANSIColor::Conditional (from Perl distribution Term-ANSIColor-Conditional), released on 2018-12-02.
 
 =head1 SYNOPSIS
 
@@ -134,9 +134,9 @@ feature.
 
 L<Term::ANSIColor>
 
-These modules also respect the C<COLOR> environment variable:
-L<Color::ANSI::Util>, L<Term::ANSITable>, L<Data::Dump::Color>, L<JSON::Color>,
-L<YAML::Tiny::Color>, L<App::diffwc>, L<App::rsynccolor>.
+These modules also respect the C<NO_COLOR> and/or the C<COLOR> environment
+variable: L<Color::ANSI::Util>, L<Text::ANSITable>, L<Data::Dump::Color>,
+L<JSON::Color>, L<YAML::Tiny::Color>, L<App::diffwc>, L<App::rsynccolor>.
 
 =head1 AUTHOR
 
